#!/usr/bin/python3
# -*- coding: utf-8 -*-

#  Copyright © 2009-2013  B. Clausius <barcc@gmx.de>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import print_function

import os, sys, re

from send_tracebacks import send_dbus_message, send_dbus_clear

re_dict = { 'file': r'(?P<file>[^:]*)',
            'line': r'(?P<line>[0-9]+)',
            'offs': r'(?P<offs>[0-9]+)',
            'err' : r' *(?P<err>[^:]*)',
            'msg' : r' *(?P<msg>.*)',}
re_default = {
            'file': '',
            'line': 1,
            'offs': 0,
            'err' : 'Error',
            'msg' : '',}

re_errors = [ ('cython',     '^{file}:{line}:{offs}:{msg}$'),
              ('gcc',        '^{file}:{line}:{err}:{msg}$'),
              ('gcc group',  '^{file}:{err}:$'),
              ('grep -rn',   '^{file}:{line}:{msg}$'),
              ('message',    '^{err}:{msg}$'),
              #('else',       '^{file}:({line}:)?({offs}:)?({err}:)?{msg}$'),
            ]
re_errors = [(k,re.compile(v.format(**re_dict))) for k,v in re_errors]
re_filename_replace = [ re.compile(r'^(.*)build/temp[^/]*/(.*)_c(\..*)$'),
                        re.compile(r'^(.*)build/temp[^/]*/(.*)$'),
                        ]

def main():
    send_dbus_clear()
    g_group = None
    g_sublist = None
    for l in sys.stdin:
        l = l.rstrip('\n')
        print(l)
        for re_key, re_error in re_errors:
            m = re_error.match(l)
            if m is not None:
                g = m.groupdict()
                for k in re_default.keys():
                    if g.get(k) is None:
                        g[k] = re_default[k]
                #print '---- found %s ----' % re_key
                #print 'line:', l
                #print 're:', re_error.pattern
                #print g
                filename = g['file']
                for r in re_filename_replace:
                    m = r.match(filename)
                    if m is not None:
                        filename_ = os.path.realpath(''.join(m.groups()))
                        if os.path.exists(filename_):
                            filename = filename_
                            break
                if os.path.exists(filename):
                    filename = os.path.realpath(filename)
                else:
                    print(filename, 'does not exist')
                line_no = int(g['line'])
                offset = int(g['offs'])
                
                if g_group:
                    if re_key == 'gcc':
                        g_group[-1].append((filename, line_no, g['err'], g['msg']))
                        break
                    else:
                        send_dbus_message(*g_group)
                        g_group = None
                if re_key == 'gcc group':
                    g_group = [g['err'], g['msg'], filename, line_no, offset, []]
                else:
                    send_dbus_message(g['err'], g['msg'], filename, line_no, offset)
                break
    if g_group:
        send_dbus_message(*g_group)
    
def test():
    filename = os.path.realpath(__file__)
    #args = ('TypeError', 'only a test', filename, 37, 0,
    #            [(filename, 38, test.func_name, 'Hallo')])
    args = ('Error', 'only a test', filename, 38)
    print(args)
    #send_dbus_message('Error', 'only a test', __file__, 34)
    send_dbus_message(*args)

if __name__ == '__main__':
    sys.exit(main())


