#!/usr/bin/python
# -*- coding: utf-8 -*-

#  Copyright © 2009-2011  B. Clausius <barcc@gmx.de>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys, os
import dbus

if False:   # Set to True to enable logging
    import logging
    from logging import debug
    logging.basicConfig(
        filename='/tmp/send-dbus-traceback.log',
        level=logging.DEBUG,
        format="%(pid)-5d %(asctime)-15s %(message)s")
else:
    debug = lambda *args,**kwargs: None
extra = {'pid': os.getpid()}


def main():
    debug('++++ start ++++', extra=extra)
    
    session_bus = dbus.SessionBus()
    dbus_object = session_bus.get_object('net.launchpad.gedit-python-traceback','/TBR')
    dbus_interface = dbus.Interface(dbus_object,
                                dbus_interface='net.launchpad.PyTracebackReceiverInterface')
    debug('dbus initialized', extra=extra)
    
    line = sys.stdin.read()
    debug('stdin read: %r', line, extra=extra)
    timestamp, command = eval(line)
    timestamp = float(timestamp)
    if command == 'CLEAR':
        debug('command CLEAR', extra=extra)
        dbus_object.Clear(timestamp)
    else:
        exc_name, message, tb_list, filename, line_no, offset = eval(command)
        debug('%s: "%s" %s', exc_name, filename, line_no, extra=extra)
        tb_list_dbus = dbus.Array(signature='(siss)')
        tb_list_dbus += tb_list
        debug('tb list created', extra=extra)
        dbus_object.Display(timestamp, exc_name, message, tb_list_dbus, filename, line_no, offset)
    debug('----- end -----', extra=extra)

if __name__ == '__main__':
    try:
        main()
    except Exception as e:
        debug('!!!! error !!!!', extra=extra)
        debug(e, extra=extra)
        debug('---- error ----', extra=extra)

