#!/usr/bin/python3
# -*- coding: utf-8 -*-

#  Copyright © 2010-2013  B. Clausius <barcc@gmx.de>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import print_function

import sys, os
from glob import glob
from distutils.core import setup


setup(
    name='gedit-python-traceback',
    version='1.3~alpha1',
    license='GPL-3',
    author='B Clausius',
    author_email='barcc@gmx.de',
    description='Redirect python tracebacks to gedit',
    long_description=
'''Easy navigation to the source of Python exceptions.

This package consists of two parts:
 * `send_tracebacks`, a Python module that can replace the exception- and/or
   warning-hook, so that messages are not only written to stdout, but send
   over D-Bus to the gedit plugin.
 * `Python Traceback`, a gedit plugin that provides the D-Bus interface and
   shows the received message in the bottom pane. If a row is activated by
   a double click or enter key, the file is opened at the relevant line.

There are different ways to use the plugin:
 1. Redirect tracebacks from every Python process on your system
 2. Redirect tracebacks just for a single Python application
 3. Send an arbitrary message to gedit
For more information see README
''',
    url='https://launchpad.net/gedit-python-traceback',

    packages=['send_tracebacks'],
    data_files=[
                ('lib/gedit/plugins/', ['python-traceback.plugin']),
                ('lib/gedit/plugins/python-traceback/', glob('python-traceback/*.??')), # *.py, *.ui
               ],
    )

